import requests
from rest_framework.permissions import BasePermission


crm_url = ''
def arbache_dominio_url(dominio):
    """
        Define o domínio Arbache que será
        verificada a permissão da requisição.
    """
    if not dominio:
        return ''

    global crm_url

    crm_url = dominio

    return crm_url


class AuthPermission(BasePermission):
    """
        Permissão de usuário logado em perfil válido
        para todas as aplicações Arbache.
    """
    message = 'Perfil inválido'

    def has_permission(self, request, view):
        """
            Consulta a validade da credencial de autenticação informada.
        """
        perfil = request.query_params.get('perfil', False)
        if not perfil:
            return False

        if not request.headers.get('Authorization', False):
            return False

        try:
            response = requests.get(
                f'{crm_url}/backend/autorizacao/?perfil={perfil}',
                headers={
                    'Authorization': request.headers['Authorization'],
                    'content-type': 'application/json'
                },
            )
        except Exception:
            return False

        if response.status_code != 200:
            return False

        response_obj = response.json()
        request.user = response_obj['email']
        request.level = response_obj['level']
        request.perfil = perfil
        request.token = request.headers['Authorization'].split(' ')[-1]

        return True


class AuthAppPermission(BasePermission):
    """
        Permissão de app registrada através de token
        para todas as aplicações Arbache.
    """

    def has_permission(self, request, view):
        """
            Permissão para verificar se a aplicação está com o token
            autenticado no CRM
        """

        try:

            request.token = request.headers['Authorization']

            response = requests.get(
                f'{crm_url}/backend/app/autorizacao/',
                headers={
                    'Authorization': request.headers['Authorization'],
                    'content-type': 'application/json'
                },
            )
        except Exception:
            return False

        if response.status_code != 200:
            return False

        return True
